# Google SERP API
[Scrapeit Cloud](https://scrape-it.cloud/) - Web Scraping API with Proxy Rotation. Get valuable data at scale in HTML format from any website without need for a proxy.

Interface to call [Google SERP API](https://scrape-it.cloud/google-search-api/) easily from Python.

## Install

    pip install google-serp-api

## Usage
Signup to Scrapeit Cloud to  [get your API key](https://app.scrape-it.cloud/sign-up)  and some free credits to get started.

    >>> from google_serp_api import ScrapeitCloudClient
    >>>
    >>> client = ScrapeitCloudClient(api_key='INSERT_YOUR_API_KEY_HERE')
    >>>
    >>> response = client.scrape(
        params={
            "keyword": "pizza",
            "country": "US",
            "num_results": 10,
            "domain": "com"
        }
    )
    >>>
    >>> response.text
    '{"status":"ok","scrapingResult":{"currentPage":1,"keyword":"pizza","organic":[{"domain":"www.pizzahut.com","linkType":"HOME","position":1,"snippet":"DELIVERY & CARRYOUT LOCATIONS ARE OPEN! Order pizza online from a store near you. View our full menu, nutritional information, store locations, and more.Contact Us · School Lunch · Careers · Restaurant Careers","title":"Pizza Hut: Pizza Delivery | Pizza Carryout | Coupons | Wings & More","url":"https://www.pizzahut.com/","sitelinks":[{"href":"/url?q=https://www.pizzahut.com/contactus&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgJEAU&usg=AOvVaw1kJCddQOovwwu7D2ICu8XQ","title":"Contact Us","type":"INLINE"},{"href":"/url?q=https://www.pizzahut.com/school-lunch&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgJEAY&usg=AOvVaw1XreOmUmwdklpQ1qEFpg7R","title":"School Lunch","type":"INLINE"},{"href":"/url?q=https://jobs.pizzahut.com/&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgJEAc&usg=AOvVaw2o7KrOxIINSr_crNMhF0I7","title":"Careers","type":"INLINE"},{"href":"/url?q=https://jobs.pizzahut.com/restaurants/careers.php&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgJEAg&usg=AOvVaw2u8lAxbtm5KXVoz227oHME","title":"Restaurant Careers","type":"INLINE"}]},{"domain":"www.dominos.com","linkType":"LANDING","position":2,"snippet":"Order pizza, pasta, sandwiches & more online for carryout or delivery from Domino\'s. View menu, find locations, track orders. Sign up for Domino\'s email\xa0...About Pizza · Order Online · Coupons · Menu","title":"Domino\'s: Pizza Delivery & Carryout, Pasta, Chicken & More","url":"https://www.dominos.com/en/","sitelinks":[{"href":"/url?q=https://www.dominos.com/en/about-pizza/&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgKEAU&usg=AOvVaw0THBSmkvIM9dttcHmyQ-bL","title":"About Pizza","type":"INLINE"},{"href":"/url?q=https://www.dominos.com/en/pages/order/&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgKEAY&usg=AOvVaw3_zqtLbwr6oMEz91BKbP_6","title":"Order Online","type":"INLINE"},{"href":"/url?q=https://www.dominos.com/en/pages/order/coupon&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgKEAc&usg=AOvVaw3jxjpqTPqGZ75dqYTkE8Cc","title":"Coupons","type":"INLINE"},{"href":"/url?q=https://www.dominos.com/en/pages/order/menu&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q0gJ6BAgKEAg&usg=AOvVaw14skq9tuVEZRsrV_VfJGm6","title":"Menu","type":"INLINE"}]},{"domain":"wethepizza.com","linkType":"HOME","position":3,"snippet":"WE, THE PIZZA offers great pizza in Capitol Hill DC & Arlington VA. Enjoy our lunch specials, inspired wings with a handmade italian soda. Order Online Now!","title":"We The Pizza: WE, THE PIZZA | Restaurant & Delivery | Capitol Hill ...","url":"https://wethepizza.com/"},{"domain":"dc.eater.com","linkType":"LANDING","position":4,"snippet":"Jul 19, 2022 · Where to find wood-fired Neapolitan pizza, New York slices, Detroit-style squares, and free-form Roman pies.","title":"The Essential Pizza Restaurants in D.C. - Eater DC","url":"https://dc.eater.com/maps/best-pizza-restaurants-dc"},{"domain":"en.wikipedia.org","linkType":"LANDING","position":5,"snippet":"Pizza is a dish of Italian origin consisting of a usually round, flat base of leavened wheat-based dough topped with tomatoes, cheese, and often various\xa0...Place of origin: ItalyMain ingredients: Dough, sauce (usually tomato sauce), cheeseRegion or state: Campania (Naples)Course: Lunch or dinner","title":"Pizza - Wikipedia","url":"https://en.wikipedia.org/wiki/Pizza","sitelinks":[{"href":"/url?q=http://en.wikipedia.org/wiki/Italy&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Qs2Z6BAgCEAY&usg=AOvVaw0LM-l1Ht0MF11A9frBfnHO","title":"Italy","type":"INLINE"},{"href":"/url?q=http://en.wikipedia.org/wiki/Cheese&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Qs2Z6BAgCEAg&usg=AOvVaw0lO0X-QQyCDSAwJcTeZtKF","title":"cheese","type":"INLINE"},{"href":"/url?q=http://en.wikipedia.org/wiki/Campania&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Qs2Z6BAgCEAo&usg=AOvVaw1LfrqIRdlFczTJXAwViWxz","title":"Campania","type":"INLINE"},{"href":"/url?q=http://en.wikipedia.org/wiki/Naples&sa=U&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Qs2Z6BAgCEAs&usg=AOvVaw0_T-AY4SPJ8CSH1OADLjK5","title":"Naples","type":"INLINE"}]},{"domain":"www.papajohns.com","linkType":"HOME","position":6,"snippet":"Enjoy the ease of ordering delicious pizza for delivery or carryout from a Papa Johns near you. Start tracking the speed of your delivery and earn rewards\xa0...","title":"Papa Johns Pizza Delivery & Carryout - Best Deals on Pizza, Sides ...","url":"https://www.papajohns.com/"},{"domain":"m.yelp.com","linkType":"LANDING","position":7,"snippet":"Rating 4.0 (22,014) Best Pizza in Washington, DC - Wiseguy Pizza, il Canale, Pi Pizzeria, Andy\'s Pizza - Shaw, L\'Ardente, Pupatella, Lupo Pizzeria, Kouzina Angelinas Pizzeria\xa0...","title":"Pizza Washington, DC - Last Updated August 2022 - Yelp","url":"https://m.yelp.com/search?find_desc=Pizza&find_loc=Washington%2C+DC"},{"domain":"www.tripadvisor.com","linkType":"LANDING","position":8,"snippet":"Pizza Places in Washington DC ; 1. Pi Pizzeria · 1,286 reviews · “Beer not cold, although PIzza\'s lovely” ; 2. We the Pizza · 950 reviews · “Excellent pizza right\xa0...","title":"THE 10 BEST Pizza Places in Washington DC - TripAdvisor","url":"https://www.tripadvisor.com/Restaurants-g28970-c31-Washington_DC_District_of_Columbia.html"},{"domain":"www.franklypizza.com","linkType":"HOME","position":9,"snippet":"Hearth-baked pizza is our specialty. Our tiny kitchen leaves room for one thing, and that\'s pizza! Quickly baked in our oak-fired brick oven, pizzas emerge\xa0...","title":"Frankly…Pizza! - Kensington","url":"https://www.franklypizza.com/"},{"domain":"www.seriouseats.com","linkType":"LANDING","position":10,"snippet":"Our crisp, crunchy, chewy, and cheesy pizza recipes include everything from classic Neapolitan and New York pies to Sicilian and Detroit-style.","title":"Pizza Recipes - Serious Eats","url":"https://www.seriouseats.com/pizza-recipes-5117816"}],"pagination":[],"relatedKeywords":[{"keyword":"Pizza near me","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+near+me&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAI"},{"keyword":"Pizza Hut","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+Hut&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAQ"},{"keyword":"Pizza delivery near me","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+delivery+near+me&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAY"},{"keyword":"Pizza Domino","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+Domino&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAg"},{"keyword":"MOD Pizza","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=MOD+Pizza&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAo"},{"keyword":"Pizza Hut near me","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+Hut+near+me&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEAw"},{"keyword":"Pizza menu","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=Pizza+menu&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEA4"},{"keyword":"We The Pizza","path":"/search?cr=countryUS&hl=en&gl=US&ie=UTF-8&tbs=ctr:countryUS&q=We+The+Pizza&sa=X&ved=2ahUKEwiM0vD24775AhUBEmIAHbXIA54Q1QJ6BAgHEBA"}],"locals":[{"name":"Manhattan Pizza","position":1,"rating":"4.4","reviews":"552"},{"name":"Marco\'s Pizza","position":2,"rating":"4.4","reviews":"66"},{"name":"Emilio\'s Brick Oven Pizza","position":3,"rating":"4.3","reviews":"416"}]}}'
    >>>

You can find all the supported parameters on [Scrapeit Cloud documentation](https://scrape-it.cloud/docs/).
